__schema__ = {
    "type": "object",
    "additionalProperties": False,
    "properties": {
        "requires": {
            "$ref": "http://json-schema.org/draft-07/schema#/definitions/stringArray"
        },
        "backend": {
            "type": "string",
            "pattern": r"^(\w[\w\d]*)(\.\w[\w\d]*)*(:(\w[\w\d]*)(\.\w[\w\d]*))?$",
        },
        "backend-path": {
            "$ref": "http://json-schema.org/draft-07/schema#/definitions/stringArray"
        },
    },
    "required": ["requires"],
}



from . import build_system, project, tool


SCHEMA = {
    "type": "object",
    "additionalProperties": False,
    "properties": {
        "build-system": build_system.__schema__,
        "project": project.__schema__,
        "tool": tool.__schema__,
    },
}



import setuptools
import toml

with open("pyproject.toml") as pyproject_toml:
    pyproject_toml = toml.load(pyproject_toml)
    project = pyproject_toml["project"]
    tool = pyproject_toml["tool"]["pyproject-toml"]
with open(project.pop("readme"), encoding="utf-8") as readme:
    project["long_description"] = readme.read()
    project["long_description_content_type"] = "text/x-rst"
license = project.pop("license")
project["license"] = license["text"]
project["install_requires"] = project.pop("dependencies", None)
setuptools.setup(**tool, **project)
